@@ -39,16 +39,16 @@ class KGAPIDRIVE_EXPORT PermissionCreateJob : public KGAPI2::CreateJob
   public:
     explicit PermissionCreateJob(const QString &fileId,
                                  const PermissionPtr &permission,
-                                 const AccountPtr &account, QObject *parent = 0);
+                                 const AccountPtr &account, QObject *parent = nullptr);
     explicit PermissionCreateJob(const QString &fileId,
                                  const PermissionsList &permissions,
-                                 const AccountPtr &account, QObject *parent = 0);
+                                 const AccountPtr &account, QObject *parent = nullptr);
     virtual ~PermissionCreateJob();
 
   protected:
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
     KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply,
-                                                     const QByteArray &rawData) Q_DECL_OVERRIDE;
+                                                     const QByteArray &rawData) override;
 
   private:
     class Private;
